==> kubernetes-model-1.0.53-sources.jar: io/fabric8/kubernetes/api/model/ExecActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class ExecActionBuilder extends ExecActionFluentImpl<ExecActionBuilder> implements VisitableBuilder<ExecAction,ExecActionBuilder>{

    ExecActionFluent<?> fluent;
    Boolean validationEnabled;

    public ExecActionBuilder(){
            this(true);
    }
    public ExecActionBuilder(Boolean validationEnabled){
            this(new ExecAction(), validationEnabled);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent){
            this(fluent, true);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ExecAction(), validationEnabled);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent,ExecAction instance){
            this(fluent, instance, true);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent,ExecAction instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommand(instance.getCommand()); 
            this.validationEnabled = validationEnabled; 
    }
    public ExecActionBuilder(ExecAction instance){
            this(instance,true);
    }
    public ExecActionBuilder(ExecAction instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommand(instance.getCommand()); 
            this.validationEnabled = validationEnabled; 
    }

    public ExecAction build(){
            ExecAction buildable = new ExecAction(fluent.getCommand());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExecActionBuilder that = (ExecActionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/ExecActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ExecActionBuilder extends ExecActionFluentImpl<ExecActionBuilder> implements VisitableBuilder<ExecAction,ExecActionBuilder>{

    ExecActionFluent<?> fluent;
    Boolean validationEnabled;

    public ExecActionBuilder(){
            this(true);
    }
    public ExecActionBuilder(Boolean validationEnabled){
            this(new ExecAction(), validationEnabled);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent){
            this(fluent, true);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ExecAction(), validationEnabled);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent,ExecAction instance){
            this(fluent, instance, true);
    }
    public ExecActionBuilder(ExecActionFluent<?> fluent,ExecAction instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommand(instance.getCommand()); 
            this.validationEnabled = validationEnabled; 
    }
    public ExecActionBuilder(ExecAction instance){
            this(instance,true);
    }
    public ExecActionBuilder(ExecAction instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommand(instance.getCommand()); 
            this.validationEnabled = validationEnabled; 
    }

    public ExecAction build(){
            ExecAction buildable = new ExecAction(fluent.getCommand());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExecActionBuilder that = (ExecActionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
